/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * © 2016 OX Software GmbH
 *
 * @author Ingo Schmidt-Rosbiegal <ingo.schmidt-rosbiegal@open-xchange.com>
 */

define('io.ox/office/portal/text/main', [
    'io.ox/office/portal/mainhelper'
], function (MainHelper) {

    'use strict';

    return MainHelper.createLauncher('text', _.noI18n('Text'), {
        appTourPath: 'io.ox/office/portal/text/fulltour'
    });

});
